@@ -3,7 +3,6 @@ package Slackware::Slackget::Config;
 use warnings;
 use strict;
 
-$XML::Simple::PREFERRED_PARSER='XML::Parser';
 use XML::Simple;
 
 =head1 NAME
@@ -51,7 +50,7 @@ sub new
 {
 	my ($class,$file) = @_ ;
 	return undef unless(-e $file && -r $file);
-	my $self= XMLin($file , ForceArray => ['li']) or return undef;
+	my $self= XMLin($file) or return undef;
 # 	use Data::Dumper;
 # 	print Dumper($self);
 	return undef unless(defined($self->{common}));
@@ -62,10 +61,6 @@ sub new
 		$self->{'plugins'}->{'list'}->{'plug-in'}->{$tmp->{'id'}} = $tmp;
 		delete($self->{'plugins'}->{'list'}->{'plug-in'}->{$tmp->{'id'}}->{'id'});
 	}
-	if($ENV{SG_DAEMON_DEBUG}){
-		require Data::Dumper;
-		print Data::Dumper::Dumper( $self ),"\n";
-	}
 	bless($self,$class);
 	return $self;
 }
@@ -354,7 +349,7 @@ You can also look for information at:
 
 =item * Infinity Perl website
 
-L<http://www.infinityperl.org/category/slack-get>
+L<http://www.infinityperl.org>
 
 =item * slack-get specific website
 
